joblib.Memory — joblib 0.11.1.dev0 documentation

# joblib.Memory

class `joblib.` `Memory`(location=None, backend='local', cachedir=None, mmap_mode=None, compress=False, verbose=1, bytes_limit=None, backend_options={})

  A context object for caching a function’s return value each time it is called with the same input arguments.

  All values are cached on the filesystem, in a deep directory structure.

  see Reference documentation of the Memory class